Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(397)

Unified Diff: src/heap/spaces.cc

Issue 2549773002: Internalize strings in-place (Closed)
Patch Set: rebased Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap/scavenger.cc ('k') | src/ia32/code-stubs-ia32.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/spaces.cc
diff --git a/src/heap/spaces.cc b/src/heap/spaces.cc
index 2e6ded546f45ecc33b2ff90b31d57d89d59685a3..0feba10c16d05aa708581aee010fcdd927584a93 100644
--- a/src/heap/spaces.cc
+++ b/src/heap/spaces.cc
@@ -3156,11 +3156,13 @@ void LargeObjectSpace::Verify() {
// We have only code, sequential strings, external strings
// (sequential strings that have been morphed into external
// strings), fixed arrays, byte arrays, and constant pool arrays in the
// large object space.
CHECK(object->IsAbstractCode() || object->IsSeqString() ||
- object->IsExternalString() || object->IsFixedArray() ||
- object->IsFixedDoubleArray() || object->IsByteArray());
+ object->IsExternalString() || object->IsThinString() ||
+ object->IsFixedArray() || object->IsFixedDoubleArray() ||
+ object->IsByteArray());
// The object itself should look OK.
object->ObjectVerify();
« no previous file with comments | « src/heap/scavenger.cc ('k') | src/ia32/code-stubs-ia32.cc » ('j') | no next file with comments »
@@ -3156,11 +3156,13 @@ void LargeObjectSpace::Verify() {
// We have only code, sequential strings, external strings
// (sequential strings that have been morphed into external
- // strings), fixed arrays, byte arrays, and constant pool arrays in the
- // large object space.
+ // strings), thin strings (sequential strings that have been
+ // morphed into thin strings), fixed arrays, byte arrays, and
+ // constant pool arrays in the large object space.
CHECK(object->IsAbstractCode() || object->IsSeqString() ||

Powered by Google App Engine
This is Rietveld 408576698